@@ -98,20 +98,20 @@ func (s *Source) Init(aCtx context.Context, name string, jobId sources.JobID, so
 }
 
 func (s *Source) Validate(ctx context.Context) []error {
-	var errors []error
+	var errs []error
 	visitor := func(c context.Context, defaultRegionClient *s3.S3, roleArn string, buckets []string) {
 		roleErrs := s.validateBucketAccess(c, defaultRegionClient, roleArn, buckets)
 		if len(roleErrs) > 0 {
-			errors = append(errors, roleErrs...)
+			errs = append(errs, roleErrs...)
 		}
 	}
 
 	err := s.visitRoles(ctx, visitor)
 	if err != nil {
-		errors = append(errors, err)
+		errs = append(errs, err)
 	}
 
-	return errors
+	return errs
 }
 
 // setMaxObjectSize sets the maximum size of objects that will be scanned. If
@@ -421,16 +421,16 @@ func (s *Source) pageChunker(ctx context.Context, client *s3.S3, chunksChan chan
 func (s *Source) validateBucketAccess(ctx context.Context, client *s3.S3, roleArn string, buckets []string) []error {
 	shouldHaveAccessToAllBuckets := roleArn == ""
 	wasAbleToListAnyBucket := false
-	var errors []error
+	var errs []error
 
 	for _, bucket := range buckets {
 		if common.IsDone(ctx) {
-			return append(errors, ctx.Err())
+			return append(errs, ctx.Err())
 		}
 
 		regionalClient, err := s.getRegionalClientForBucket(ctx, client, roleArn, bucket)
 		if err != nil {
-			errors = append(errors, fmt.Errorf("could not get regional client for bucket %q: %w", bucket, err))
+			errs = append(errs, fmt.Errorf("could not get regional client for bucket %q: %w", bucket, err))
 			continue
 		}
 
@@ -439,19 +439,19 @@ func (s *Source) validateBucketAccess(ctx context.Context, client *s3.S3, roleAr
 		if err == nil {
 			wasAbleToListAnyBucket = true
 		} else if shouldHaveAccessToAllBuckets {
-			errors = append(errors, fmt.Errorf("could not list objects in bucket %q: %w", bucket, err))
+			errs = append(errs, fmt.Errorf("could not list objects in bucket %q: %w", bucket, err))
 		}
 	}
 
 	if !wasAbleToListAnyBucket {
 		if roleArn == "" {
-			errors = append(errors, fmt.Errorf("could not list objects in any bucket"))
+			errs = append(errs, fmt.Errorf("could not list objects in any bucket"))
 		} else {
-			errors = append(errors, fmt.Errorf("role %q could not list objects in any bucket", roleArn))
+			errs = append(errs, fmt.Errorf("role %q could not list objects in any bucket", roleArn))
 		}
 	}
 
-	return errors
+	return errs
 }
 
 func (s *Source) visitRoles(ctx context.Context, f func(c context.Context, defaultRegionClient *s3.S3, roleArn string, buckets []string)) error {
