@@ -65,14 +65,14 @@ func NewSyslog(sourceType sourcespb.SourceType, jobID sources.JobID, sourceID so
 
 // Validate validates the configuration of the source.
 func (s *Source) Validate(ctx context.Context) []error {
-	var errors []error
+	var errs []error
 
 	if s.conn.TlsCert != nilString || s.conn.TlsKey != nilString {
 		if s.conn.TlsCert == nilString || s.conn.TlsKey == nilString {
-			errors = append(errors, fmt.Errorf("tls cert and key must both be set"))
+			errs = append(errs, fmt.Errorf("tls cert and key must both be set"))
 		}
 		if _, err := tls.LoadX509KeyPair(s.conn.TlsCert, s.conn.TlsKey); err != nil {
-			errors = append(errors, fmt.Errorf("error loading tls cert and key: %s", err))
+			errs = append(errs, fmt.Errorf("error loading tls cert and key: %s", err))
 		}
 	}
 
@@ -81,24 +81,24 @@ func (s *Source) Validate(ctx context.Context) []error {
 		case "tcp":
 			srv, err := net.Listen(s.conn.Protocol, s.conn.ListenAddress)
 			if err != nil {
-				errors = append(errors, fmt.Errorf("error listening on tcp socket: %s", err))
+				errs = append(errs, fmt.Errorf("error listening on tcp socket: %s", err))
 			}
 			srv.Close()
 		case "udp":
 			srv, err := net.ListenPacket(s.conn.Protocol, s.conn.ListenAddress)
 			if err != nil {
-				errors = append(errors, fmt.Errorf("error listening on udp socket: %s", err))
+				errs = append(errs, fmt.Errorf("error listening on udp socket: %s", err))
 			}
 			srv.Close()
 		}
 	}
 	if s.conn.Protocol != "tcp" && s.conn.Protocol != "udp" {
-		errors = append(errors, fmt.Errorf("protocol must be 'tcp' or 'udp', got: %s", s.conn.Protocol))
+		errs = append(errs, fmt.Errorf("protocol must be 'tcp' or 'udp', got: %s", s.conn.Protocol))
 	}
 	if s.conn.Format != "rfc5424" && s.conn.Format != "rfc3164" {
-		errors = append(errors, fmt.Errorf("format must be 'rfc5424' or 'rfc3164', got: %s", s.conn.Format))
+		errs = append(errs, fmt.Errorf("format must be 'rfc5424' or 'rfc3164', got: %s", s.conn.Format))
 	}
-	return errors
+	return errs
 }
 
 // Ensure the Source satisfies the interface at compile time.
